==> time_machine-0.0.1.tar.gz: test/text/period_pattern_test.dart <==
// Portions of this work are Copyright 2018 The Time Machine Authors. All rights reserved.
// Portions of this work are Copyright 2018 The Noda Time Authors. All rights reserved.
// Use of this source code is governed by the Apache License 2.0, as found in the LICENSE.txt file.
import 'dart:async';
import 'dart:math' as math;
import 'dart:mirrors';

import 'package:time_machine/time_machine.dart';
import 'package:time_machine/time_machine_calendars.dart';
import 'package:time_machine/time_machine_globalization.dart';
import 'package:time_machine/time_machine_patterns.dart';
import 'package:time_machine/time_machine_text.dart';
import 'package:time_machine/time_machine_utilities.dart';

import 'package:test/test.dart';
import 'package:matcher/matcher.dart';
import 'package:time_machine/time_machine_timezones.dart';

import '../time_machine_testing.dart';
import 'pattern_test_base.dart';
import 'pattern_test_data.dart';
import 'test_cultures.dart';
import 'text_cursor_test_base_tests.dart';

Future main() async {
  await runTests();
}

/// A container for test data for formatting and parsing [Period] objects.
/*sealed*/ class Data extends PatternTestData<Period> {
// Irrelevant
/*protected*/ @override Period get DefaultTemplate => new Period.fromDays(0);

  Data([Period value = null]) : super(value ?? new Period.fromDays(0)) {
    this.StandardPattern = PeriodPattern.Roundtrip;
  }

  Data.builder(PeriodBuilder builder) : this(builder.Build());

  @internal
  @override
  IPattern<Period> CreatePattern() => StandardPattern;
}

==> time_machine-0.0.2.tar.gz: test/text/period_pattern_test.dart <==
// Portions of this work are Copyright 2018 The Time Machine Authors. All rights reserved.
// Portions of this work are Copyright 2018 The Noda Time Authors. All rights reserved.
// Use of this source code is governed by the Apache License 2.0, as found in the LICENSE.txt file.
import 'dart:async';
import 'dart:math' as math;
import 'dart:mirrors';

import 'package:time_machine/time_machine.dart';
import 'package:time_machine/time_machine_calendars.dart';
import 'package:time_machine/time_machine_globalization.dart';
import 'package:time_machine/time_machine_patterns.dart';
import 'package:time_machine/time_machine_text.dart';
import 'package:time_machine/time_machine_utilities.dart';

import 'package:test/test.dart';
import 'package:matcher/matcher.dart';
import 'package:time_machine/time_machine_timezones.dart';

import '../time_machine_testing.dart';
import 'pattern_test_base.dart';
import 'pattern_test_data.dart';
import 'test_cultures.dart';
import 'text_cursor_test_base_tests.dart';

Future main() async {
  await runTests();
}

/// A container for test data for formatting and parsing [Period] objects.
/*sealed*/ class Data extends PatternTestData<Period> {
// Irrelevant
/*protected*/ @override Period get DefaultTemplate => new Period.fromDays(0);

  Data([Period value = null]) : super(value ?? new Period.fromDays(0)) {
    this.StandardPattern = PeriodPattern.roundtrip;
  }

  Data.builder(PeriodBuilder builder) : this(builder.build());

  @internal
  @override
  IPattern<Period> CreatePattern() => StandardPattern;
}
